Define a Singleton class which can hold a CV dictionary (so we do not have to load the .obo files over and over again)
Define a Singleton class which can hold a CV dictionary (so we do not have to load the .obo files over and over again)
R6P::Singleton -> CVDictionarySingleton
dataStores the data of the singleton. Set the data once before using the singleton all over the place
clone()The objects of this class are cloneable with this method.
CVDictionarySingleton$clone(deep = FALSE)
deepWhether to make a deep clone.