Details of the software used to create the QC metrics
accessionAccession number identifying the term within its controlled vocabulary (pattern: ^[A-Z]+:[A-Z0-9]+$).
nameName of the controlled vocabulary term describing the software tool.
versionVersion number of the software tool.
uriPublicly accessible URI of the software tool or documentation.
description[optional] Definition of the controlled vocabulary term.
value[optional] Value of the software tool.