The central class to store QC information
accessionAccession number identifying the term within its controlled vocabulary (pattern: ^[A-Z]+:[A-Z0-9]+$).
nameName of the controlled vocabulary element describing the metric.
description[optional] Definition of the controlled vocabulary term.
value[optional] Value of the metric (single value, n-tuple, table, matrix). The structure is not checked by our mzQC implementation and must be handled by the caller
unit[optional] Array of unit(s), stored as MzQcvParameter