Define a Singleton class which holds the full raw filenames (+path) and their PSI-MS CV terms for usage in the mzQC metadata
Define a Singleton class which holds the full raw filenames (+path) and their PSI-MS CV terms for usage in the mzQC metadata
R6P::Singleton -> QCMetaFilenames
dataStores the data of the singleton. Set the data once before using the singleton all over the place
clone()The objects of this class are cloneable with this method.
QCMetaFilenames$clone(deep = FALSE)
deepWhether to make a deep clone.