lcpCount: Count the number of chars of the longest common prefix

View source: R/fcn_misc.R

lcpCountR Documentation

Count the number of chars of the longest common prefix

Description

Count the number of chars of the longest common prefix

Usage

lcpCount(x)

Arguments

x

Vector of strings with common prefix

Value

Length of LCP


PTXQC documentation built on April 23, 2026, 9:11 a.m.